@@ -215,6 +215,7 @@ COMMON_EXCEPTIONS = (
     E("univention.lib.umc.ConnectionError: .*Could not send request.*SSLCertVerificationError", ['univention-self-service-invitation'], 53670),
     E("FileNotFoundError: \\[Errno 2\\] No such file or directory: '/etc/machine.secret'", ['univention/lib/umc.py.*in authenticate_with_machine_account'], 53670),
     E(r"TypeError: modify\(\) got an unexpected keyword argument 'rename_callback'", ['_register_app'], 54578),
+    E('sqlite3.OperationalError: no such table: S4 rejected', 'stdin', 54586),
     # during UCS 5.0-0-errata updates
     E(r"TypeError: __init__\(\) got an unexpected keyword argument 'cli_enabled'", ['_register_app'], 54584),
 
@@ -272,10 +273,12 @@ COMMON_EXCEPTIONS = (
     E("ucsschool.importer.exceptions.MoveError: Error moving.*from school 'NoSchool' to", ['in create_and_modify_users'], 53564),
     E("ucsschool.importer.exceptions.UniqueIdError: Username '.*' is already in use by .*", ['in create_and_modify_users'], 53564),
     E('ucsschool.importer.exceptions.UserValidationError: <unprintable UserValidationError object>', ['in create_and_modify_users'], 53564),
+    E(r"ucsschool.importer.exceptions.UserValidationError: .* ValidationError\({'school_classes': \[\"School '302_http_api_no_school' in 'school_classes' is missing in the users 'school\(s\)' attribute.\"\]}\)", ['in create_and_modify_users']),
     E("ucsschool.importer.exceptions.UnknownSchoolName: School '.*' does not exist.", ['in create_and_modify_users'], 53564),
     E("univention.admin.uexceptions.pwToShort: Password policy error: The password is too short, at least [0-9] characters needed!", ['ucsschool/importer/mass_import']),
     E(".*WARNING/ForkPoolWorker.* in create_and_modify_users", [], 53564),
     E(r"ucsschool.lib.models.attributes.ValidationError: .*is missing in the users 'school\(s\)' attributes", ['in create_and_modify_users'], 53564),
+    E(r"ucsschool.lib.models.attributes.ValidationError: {'school_classes': \[\"School '302_http_api_no_school' in 'school_classes' is missing in the users 'school\(s\)' attribute.\"\]}", ['in create_and_modify_users']),
     E("Exception: Empty user.input_data.", ['test228_input_data_pyhook.py'], 53564),
     E("ConnectionForced:.*broker forced connection closure with reason .*shutdown", ['celery'], 53564),
     E(r"error: \[Errno 104\] Connection reset by peer", ['celery'], (53671, 53564)),
